@@ -12,7 +12,7 @@ use Moose::Role;
 has 'name' =>( is => 'ro' );
 
 use lib '../lib';
-use MooseX::ShortCut::BuildInstance qw( build_instance );
+use MooseX::ShortCut::BuildInstance;
 use Test::More;
 use Test::Moose;
 
